==> xl-react-components-0.16.62.tgz: package/app/xl-react-widget/xl-react-widget-file-upload/xl-react-widget-file-upload.js <==
import React, {Component} from 'react';
import PropTypes from 'prop-types';
import {getModelValue, isComponentDisabled, resetPristinity} from '../../utils/components-utils';
import {XlReactWidgetContainerProps} from '../xl-react-widget-props';
import {
    computeInitialState,
    computeNextPropsState,
    computeOnChangeState,
    getValidators
} from '../../services/component-service';
import {XlReactWidgetFileUploadComponent} from './xl-react-widget-file-upload-component';

export class XlReactWidgetFileUpload extends Component {
    static propTypes = {
        metadata: PropTypes.object,
        model: PropTypes.object,
        ...XlReactWidgetContainerProps
    };

    static defaultProps = {validators: []};

    constructor(props) {
        super(props);
        this.state = {
            currentProgress: 0,
            state: 'pristine'
        };
    }

    componentWillMount() {
        const model = getModelValue(this.props, 'model', {});
        computeInitialState(this, this.props, getValidators(this.props), model);
    }

    componentWillReceiveProps(nextProps) {
        computeNextPropsState(this, nextProps, this.state, getValidators(nextProps));
    }

    onChange = (model) => {
        computeOnChangeState(this, this.props, getValidators(this.props), model);
    };

    api = {resetPristinity: (config) => resetPristinity(this, this.props, config)};

    applyNewState = (newState) => {
        this.setState(newState);
    };

    render() {
        const {
            metadata: {
                auto: autoUpload,
                browseButtonType,
                description,
                fileNameField,
                label,
                required,
                requestHeaders,
                uploadUrl
            },
            onValidityChange
        } = this.props;

        const {
            currentProgress, message, model, pristine, state: currentStatus, valid
        } = this.state;

        const disabled = currentStatus === 'progress' || isComponentDisabled(this.props);

        return <XlReactWidgetFileUploadComponent {...({
            autoUpload,
            browseButtonType: browseButtonType,
            currentProgress,
            currentStatus,
            description,
            disabled,
            fileNameField,
            handleOnChange: this.onChange,
            handleUploadError: this.applyNewState,
            handleUploadingProgress: this.applyNewState,
            handleUploadSuccess: this.applyNewState,
            label,
            message,
            model,
            onValidityChange,
            pristine,
            requestHeaders,
            required,
            uploadUrl,
            valid
        })}
        />;
    }
}

==> xl-react-components-0.21.12.tgz: package/app/xl-react-widget/xl-react-widget-file-upload/xl-react-widget-file-upload.js <==
import React, {Component} from 'react';
import PropTypes from 'prop-types';
import {getModelValue, isComponentDisabled, resetPristinity} from '../../utils/components-utils';
import {
    computeInitialState,
    computeNextPropsState,
    computeOnChangeState,
    getValidators
} from '../../services/component-service';
import {XlReactWidgetFileUploadComponent} from './xl-react-widget-file-upload-component';

export class XlReactWidgetFileUpload extends Component {
    static propTypes = {
        disabled: PropTypes.bool,
        metadata: PropTypes.object,
        model: PropTypes.object,
        onValidityChange: PropTypes.func
    };

    static defaultProps = {validators: []};

    constructor(props) {
        super(props);
        this.state = {
            currentProgress: 0,
            state: 'pristine'
        };
    }

    UNSAFE_componentWillMount() {
        const model = getModelValue(this.props, 'model', {});
        computeInitialState(this, this.props, getValidators(this.props), model);
    }

    UNSAFE_componentWillReceiveProps(nextProps) {
        computeNextPropsState(this, nextProps, this.state, getValidators(nextProps));
    }

    onChange = (model) => {
        computeOnChangeState(this, this.props, getValidators(this.props), model);
    };

    api = {resetPristinity: (config) => resetPristinity(this, this.props, config)};

    applyNewState = (newState) => {
        this.setState(newState);
    };

    render() {
        const {
            metadata: {
                auto: autoUpload,
                browseButtonType,
                description,
                fileNameField,
                label,
                required,
                requestHeaders,
                uploadUrl
            },
            onValidityChange
        } = this.props;

        const {
            currentProgress, message, model, pristine, state: currentStatus, valid
        } = this.state;

        const disabled = currentStatus === 'progress' || isComponentDisabled(this.props);

        return <XlReactWidgetFileUploadComponent {...({
            autoUpload,
            browseButtonType: browseButtonType,
            currentProgress,
            currentStatus,
            description,
            disabled,
            fileNameField,
            handleOnChange: this.onChange,
            handleUploadError: this.applyNewState,
            handleUploadingProgress: this.applyNewState,
            handleUploadSuccess: this.applyNewState,
            label,
            message,
            model,
            onValidityChange,
            pristine,
            requestHeaders,
            required,
            uploadUrl,
            valid
        })}
        />;
    }
}
